# Generated by Django 3.2.13 on 2022-09-26 15:14

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gonk', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='max_retries',
            field=models.PositiveIntegerField(default=3),
        ),
        migrations.AddField(
            model_name='task',
            name='retries',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='task',
            name='retry_time',
            field=models.DurationField(default=datetime.timedelta(seconds=0)),
        ),
        migrations.AddField(
            model_name='task',
            name='retryable',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='task',
            name='status',
            field=models.CharField(choices=[('ERROR', 'Error'), ('PENDI', 'To DO'), ('DOING', 'Doing'), ('DONE', 'Done'), ('CANCG', 'Cancelling'), ('CANCD', 'Canceled'), ('TOREV', 'To Revert'), ('REVTG', 'Reverting'), ('REVTD', 'Reverted'), ('RTRNG', 'Retrying'), ('RTERR', 'Retry error')], default='PENDI', max_length=5),
        ),
    ]
