# Generated by Django 3.2.13 on 2022-10-03 10:32

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gonk', '0002_auto_20220926_1514'),
    ]

    operations = [
        migrations.AlterField(
            model_name='task',
            name='retry_time',
            field=models.DurationField(blank=True, default=datetime.timedelta(0), null=True),
        ),
    ]
